# Quickstart Guide

You will need:

- `python` 3.8 or greater: [https://www.python.org/downloads/](https://www.python.org/downloads/)

*mixture_experimentalist is a part of the `autora` package:

```shell
pip install -U autora["experimentalist-sampler-mixture_experimentalist"]
```


Check your installation by running:
```shell
python -c "from autora.experimentalist.sampler.mixture_experimentalist import Example"
```
